@@ -62,8 +62,8 @@ class DataModel:  # pylint: disable=too-few-public-methods
         # mappings are required
         if not isinstance(config.get("mappings"), list):
             raise AssertionError('Field "mappings" of type list')
-        self.paths: Dict[str, Fields] = dict()  # setup paths mappings
-        self.methods: Dict[str, Callable] = dict()  # setup method mappings
+        self.paths: Dict[str, Fields] = {}  # setup paths mappings
+        self.methods: Dict[str, Callable] = {}  # setup method mappings
 
         # body is optional in a data model
         self.body = ""
