@@ -175,17 +175,24 @@ class Detection(ABC):
         self._default_dedup_string = "defaultDedupString:{}".format(self.detection_id)
         self._auxiliary_function_definitions = self._check_defined_functions()
 
-        if config.get("filters", None) is None:
+        filts = config.get("filters")
+        if filts is None:
             self.filters: List[Filter] = []
-        elif isinstance(config["filters"], Filter):
-            self.filters = [config["filters"]]
-        elif isinstance(config["filters"], list) and all(
-            isinstance(f, Filter) for f in config["filters"]
-        ):
-            self.filters = config["filters"]
+        elif isinstance(filts, dict):
+            if filts.get("statement") is None:
+                raise TypeError("filter does not contain required 'statement' attribute")
+            self.filters = [Filter(filts["statement"])]
+        elif isinstance(filts, list) and all(isinstance(f, dict) for f in filts):
+            if any(f.get("statement") is None for f in filts):
+                raise TypeError("filter does not contain required 'statement' attribute")
+            self.filters = [Filter(f["statement"]) for f in filts]
+        elif isinstance(filts, Filter):
+            self.filters = [filts]
+        elif isinstance(filts, list) and all(isinstance(f, Filter) for f in filts):
+            self.filters = filts
         else:
             self._setup_exception = TypeError(
-                "expected 'filters' to be of type Union[List[Filter], Filter, None]"
+                "expected 'filters' to be of type Union[List[dict], dict, List[Filter], Filter, None]"
             )
             self.logger.info(
                 "error while parsing filters for detection %s",
